# -*- coding: utf-8 -*-
import os

from sphinx_celery import conf

globals().update(conf.build_config(
    'lc_celery_beat', __file__,
    project='lc_celery_beat',
    # version_dev='2.0',
    # version_stable='1.4',
    canonical_url='http://lc_celery_beat.readthedocs.io',
    webdomain='',
    github_project='celery/lc_celery_beat',
    copyright='2016',
    django_settings='proj.settings',
    include_intersphinx={'python', 'sphinx', 'django', 'celery'},
    path_additions=[os.path.join(os.pardir, 't')],
    html_logo='images/logo.png',
    html_favicon='images/favicon.ico',
    html_prepend_sidebars=[],
    apicheck_ignore_modules=[
        'lc_celery_beat.apps',
        r'lc_celery_beat.migrations.*',
    ],
))

intersphinx_mapping = globals().get('intersphinx_mapping', {})
intersphinx_mapping['celery'] = (
    'https://celery.readthedocs.io/en/main/', None)
globals().update({'intersphinx_mapping': intersphinx_mapping})

